bug-hurd
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

patch to remove the use of pathtrans in the Hurd source


From: James A Morrison
Subject: patch to remove the use of pathtrans in the Hurd source
Date: Sun, 10 Feb 2002 13:57:20 -0500 (EST)

 These should be last references to dir_pathtrans left in the hurd sources.

2002-02-11  James A. Morrison  <ja2morri@student.math.uwaterloo.ca>

        * fstests/fstests: dir_pathtrans -> dir_lookup
        * hurd/fs.defs: Likewise
        * hurd/fsys.defs: Likewise
        * libdiskfs/diskfs.h: Likewise
        * libdiskfs/fsys-getroot.c: Likewise
        * libfshelp/fshelp.h: Likewise
        * doc/hurd.texi Likewise

Index: fstests/fstests.c
===================================================================
RCS file: /cvsroot/hurd/hurd/fstests/fstests.c,v
retrieving revision 1.23
diff -u -r1.23 fstests.c
--- fstests/fstests.c   26 Feb 2001 04:14:37 -0000      1.23
+++ fstests/fstests.c   10 Feb 2002 17:19:17 -0000
@@ -59,9 +59,9 @@
 #if 0
   if ((err = dir_unlink (root, "CREATED")) && err != ENOENT)
     printf ("Error on unlink: %d\n", err);
-  else if (err = dir_pathtrans (root, "CREATED", O_WRITE | O_CREAT, 0666,
+  else if (err = dir_lookup (root, "CREATED", O_WRITE | O_CREAT, 0666,
                                &retry, pathbuf, &filetowrite))
-    printf ("Error on pathtrans: %d\n", err);
+    printf ("Error on lookup: %d\n", err);
   else if (err = io_write (filetowrite, string, strlen (string), -1, &written))
     printf ("Error on write: %d\n", err);
   else if (written != strlen (string))
Index: hurd/fs.defs
===================================================================
RCS file: /cvsroot/hurd/hurd/hurd/fs.defs,v
retrieving revision 1.47
diff -u -r1.47 fs.defs
--- hurd/fs.defs        10 Jul 2001 22:17:40 -0000      1.47
+++ hurd/fs.defs        10 Feb 2002 17:19:17 -0000
@@ -284,7 +284,7 @@
 /* Create a new file without linking it into the filesystem.  You
    still must have write permission on the specified directory, even
    though it will not actually be written.  Return in *newnode a port
-   to the file.  Flags are the same as for dir_pathtrans, but
+   to the file.  Flags are the same as for dir_lookup, but
    O_CREAT and O_TRUNC are assumed even if not specified.  */
 routine dir_mkfile (
        directory: file_t;
@@ -303,7 +303,7 @@
 /* To get or set the translator currently running on a file, use
    file_set_translator, file_get_translator, or
    file_get_translator_cntl on a port gotten with the
-   FS_LOOKUP_NOTRANS flag to dir_pathtrans.  You can send these RPCs
+   FS_LOOKUP_NOTRANS flag to dir_lookup.  You can send these RPCs
    to a port to a translated node (looked up without
    FS_LOOKUP_NOTRANS) to stack a new translator on top of the existing
    one.  */
Index: hurd/fsys.defs
===================================================================
RCS file: /cvsroot/hurd/hurd/hurd/fsys.defs,v
retrieving revision 1.27
diff -u -r1.27 fsys.defs
--- hurd/fsys.defs      10 Jul 2001 22:17:40 -0000      1.27
+++ hurd/fsys.defs      10 Feb 2002 17:19:17 -0000
@@ -51,9 +51,9 @@
        flags: int);
 
 /* Return a file to the root of the filesystem.
-   FLAGS are as for dir_pathtrans (but O_CREAT and O_EXCL are not
+   FLAGS are as for dir_lookup (but O_CREAT and O_EXCL are not
    meaningful).  DO_RETRY, RETRY_NAME, and RESULT are as
-   for dir_pathtrans.  The port should be authenticated with GEN_UIDS
+   for dir_lookup.  The port should be authenticated with GEN_UIDS
    and GEN_GIDS (except, of course, for FS_RETRY_REAUTH and 
    FS_RETRY_MAGICAL).  DOTDOT_NODE is an unauthenticated port for the
    directory in which this root is located.  */ 
Index: hurd/hurd_types.h
===================================================================
RCS file: /cvsroot/hurd/hurd/hurd/hurd_types.h,v
retrieving revision 1.41
diff -u -r1.41 hurd_types.h
--- hurd/hurd_types.h   16 Jun 2001 02:27:23 -0000      1.41
+++ hurd/hurd_types.h   10 Feb 2002 17:19:18 -0000
@@ -83,7 +83,7 @@
 #define FS_TRANS_SET      0x00000004 /* Set or clear translator */
 #define FS_TRANS_ORPHAN    0x00000008 /* Orphan the active translator.  */
 
-/* Values for retry field in fs.defs:dir_pathtrans call: */
+/* Values for retry field in fs.defs:dir_lookup call: */
 enum retry_type
 {
   FS_RETRY_NORMAL = 1,         /* Retry normally if retry_name is not null. */
Index: libdiskfs/fsys-getroot.c
===================================================================
RCS file: /cvsroot/hurd/hurd/libdiskfs/fsys-getroot.c,v
retrieving revision 1.36
diff -u -r1.36 fsys-getroot.c
--- libdiskfs/fsys-getroot.c    24 Oct 1998 07:30:45 -0000      1.36
+++ libdiskfs/fsys-getroot.c    10 Feb 2002 17:19:18 -0000
@@ -1,5 +1,6 @@
 /*
-   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998 Free Software Foundation
+   Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002 
+   Free Software Foundation
 
 This file is part of the GNU Hurd.
 
@@ -68,7 +69,7 @@
   mutex_lock (&diskfs_root_node->lock);
 
   /* This code is similar (but not the same as) the code in
-     dir-pathtrans.c that does the same thing.  Perhaps a way should
+     dir-lookup.c that does the same thing.  Perhaps a way should
      be found to share the logic.  */
 
   type = diskfs_root_node->dn_stat.st_mode & S_IFMT;
Index: libfshelp/fshelp.h
===================================================================
RCS file: /cvsroot/hurd/hurd/libfshelp/fshelp.h,v
retrieving revision 1.48
diff -u -r1.48 fshelp.h
--- libfshelp/fshelp.h  3 Jul 2001 01:10:17 -0000       1.48
+++ libfshelp/fshelp.h  10 Feb 2002 17:19:18 -0000
@@ -122,7 +122,7 @@
 /* Fetch the root from TRANSBOX.  DOTDOT is an unauthenticated port
    for the directory in which we are looking; USER specifies the ids
    of the user responsible for the call.  FLAGS are as for
-   dir_pathtrans (but O_CREAT and O_EXCL are not meaningful and are
+   dir_lookup (but O_CREAT and O_EXCL are not meaningful and are
    ignored).  The trasnbox lock (as set by fshelp_transbox_init) must
    be held before the call, and will be held upon return, but may be
    released during the operation of the call.  */
Index: doc/hurd.texi
===================================================================
RCS file: /cvsroot/hurd/hurd/doc/hurd.texi,v
retrieving revision 1.20
diff -u -r1.20 hurd.texi
--- doc/hurd.texi       12 Mar 2001 00:43:50 -0000      1.20
+++ doc/hurd.texi       9 Feb 2002 22:34:29 -0000
@@ -2516,7 +2688,7 @@
 Fetch the root from @var{transbox}.  @var{dotdot} is an unauthenticated
 port for the directory in which we are looking; @var{user} specifies the
 ids of the user responsible for the call.  @var{flags} are as for
-@code{dir_pathtrans} (but @code{O_CREAT} and @code{O_EXCL} are not
+@code{dir_lookup} (but @code{O_CREAT} and @code{O_EXCL} are not
 meaningful and are ignored).  The transbox lock (as set by
 @code{fshelp_transbox_init}) must be held before the call, and will be
 held upon return, but may be released during the operation of the call.
@@ -3956,7 +4145,7 @@
 @deftypevar int diskfs_maxsymlinks
 This variable is a positive integer which is the maximum number of
 symbolic links which can be traversed within a single call to
-@code{dir_pathtrans}.  If this is exceeded, @code{dir_pathtrans} will
+@code{dir_lookup}.  If this is exceeded, @code{dir_lookup} will
 return @code{ELOOP}.
 @end deftypevar
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: libdiskfs/diskfs.h
===================================================================
RCS file: /cvsroot/hurd/hurd/libdiskfs/diskfs.h,v
retrieving revision 1.92
diff -u -r1.92 diskfs.h
--- libdiskfs/diskfs.h  20 Aug 2001 22:44:13 -0000      1.92
+++ libdiskfs/diskfs.h  10 Feb 2002 17:19:18 -0000
@@ -47,7 +47,7 @@
   struct shared_io *mapped;
 };
 
 /* One of these is created for each node opened by dir_pathtrans. */
 struct peropen
 {
   int filepointer;
@@ -220,8 +220,8 @@
 extern int diskfs_name_max;
 
 /* The user must define this variable; it is the maximum number of
-   symlinks to be traversed within a single call to dir_pathtrans.
-   If this is exceeded, dir_pathtrans will return ELOOP.  */
+   symlinks to be traversed within a single call to dir_lookup.
+   If this is exceeded, dir_lookup will return ELOOP.  */
 extern int diskfs_maxsymlinks;
 
 /* This variable is defined by diskfs; the user should set it if
@@ -47,7 +47,7 @@
 };
 
-/* One of these is created for each node opened by dir_pathtrans. */
+/* One of these is created for each node opened by dir_lookup. */
 struct peropen
 {